<?php
/**
 * Medical Portfolio Theme Customizer.
 *
 * @package Medical Portfolio
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
 
if ( ! class_exists( 'WP_Customize_Control' ) )
    return NULL;

/**
 * A class to create a dropdown for all categories in your wordpress site
 */
 class medical_portfolio_Category_Dropdown_Custom_Control extends WP_Customize_Control
 {
    private $cats = false;

    public function __construct($manager, $id, $args = array(), $options = array())
    {
        $this->cats = get_categories($options);

        parent::__construct( $manager, $id, $args );
    }

    /**
     * Render the content of the category dropdown
     *
     * @return HTML
     */
    public function render_content()
       {
            if(!empty($this->cats))
            {
                ?>
                    <label>
                      <span class="customize-category-select-control"><?php echo esc_html( $this->label ); ?></span>
                      <select <?php $this->link(); ?>>
                           <?php
                                foreach ( $this->cats as $cat )
                                {
                                    printf('<option value="%s" %s>%s</option>', $cat->term_id, selected($this->value(), $cat->term_id, false), $cat->name);
                                }
                           ?>
                      </select>
                    </label>
                <?php
            }
       }
 }
 
function medical_portfolio_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';	
	$wp_customize->get_section( 'title_tagline'  )->title		= __('Site Titles & Logo','medical-portfolio');
	//$wp_customize->get_control( 'header_text'  )->label			= __('Display Site Title','medical-portfolio');
	$wp_customize->get_section( 'title_tagline'  )->priority	= 10;
	$wp_customize->get_section( 'colors'  )->title				= __('Logo Text & Background Color','medical-portfolio');
	$wp_customize->get_section( 'colors'  )->panel				= 'medical_portfolio_panel_design';
	$wp_customize->get_section( 'background_image'  )->panel	= 'medical_portfolio_panel_design';


	
// create an empty array
$cats = array();
 
// we loop over the categories and set the names and
// labels we need
foreach ( get_categories() as $categoriesi => $categoryy ){
    $cats[$categoryy->term_id] = $categoryy->name;
}
	
	// Top Navigation Color
	$wp_customize->add_section( 'top_navi_colorbg' , array(
    'title'      => __( 'Top Navigation Color', 'medical-portfolio' ),
	'panel'			=> 'medical_portfolio_panel_design',
    'priority'   => 64,
) );


/**************************************************
* Show Front Page
***************************************************/
	$wp_customize->add_panel('medical_portfolio_frontpageindex',
		array(
			'priority' 			=> 13,
			'capability' 		=> 'edit_theme_options',
			'theme_supports'	=> '',
			'title' 			=> __( 'Website Front Page', 'medical-portfolio' ),
			'description' 		=> __( 'Website Default Front Page options', 'medical-portfolio' ),
		)
	);
	

	
	
// Front Page Enable
$wp_customize->add_section( 'medical_portfolio_frontpage' , array(
    'title'      => __( 'Enable or Disable Front Page', 'medical-portfolio' ),
	'description' 		=> __( 'Enable or Disable default front page in website ', 'medical-portfolio' ),
    'priority'   => 1,
   'panel'			=> 'medical_portfolio_frontpageindex'
) );   


$wp_customize->add_setting('medical_portfolio_enablefrontpage',
    array(
			'default'			=> 'enable',
			'type'				=> 'theme_mod',
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
    )
);
	$wp_customize->add_control('medical_portfolio_enablefrontpage',
    array(
        'type' => 'radio',
		'settings'   => 'medical_portfolio_enablefrontpage',
        'section' => 'medical_portfolio_frontpage',
        'choices' => array(
            'enable' => __('Enable','medical-portfolio'),
            'disable' => __('Disable','medical-portfolio'),
        ) ));

		
// Woocommerce Section		
		
$wp_customize-> add_section('medical_portfolio_frontpage_woo',
    array(
    	'title'			=> __('Front Page WooCommerce','medical-portfolio'),
    	'description'	=> __('Only for front page Woocommerce settings.','medical-portfolio'),
    	'priority'		=> 3,
    	'panel'			=> 'medical_portfolio_frontpageindex'
    	)
    );
    
	
$wp_customize->add_setting('medical_portfolio_frontwoo',
    array(
			'default'			=> 'enable',
			'type'				=> 'theme_mod',
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
    )
);
	$wp_customize->add_control('medical_portfolio_frontwoo',
    array(
        'type' => 'radio',
		'label'        => __( 'Enable or Disable WooCommerce', 'medical-portfolio' ),
		'settings'   => 'medical_portfolio_frontwoo',
        'section' => 'medical_portfolio_frontpage_woo',
        'choices' => array(
            'enable' => __('Enable','medical-portfolio'),
            'disable' => __('Disable','medical-portfolio'),
        ) ));
	
	$wp_customize->add_setting('medical_portfolio_woo_sec_text',
	array(
		'default'		=> 'Featured Products',
		'sanitize_callback'	=> 'sanitize_text_field'
		
		)
	);
	
	$wp_customize->add_control('medical_portfolio_woo_sec_text',
	        array(
			'label'        => __( 'Title of WooCommerce', 'medical-portfolio' ),
	            'section' => 'medical_portfolio_frontpage_woo',
	            'settings' => 'medical_portfolio_woo_sec_text',
	            'type' => 'text'
	        )
	);

	$wp_customize->add_setting('medical_portfolio_woo_pronum',
	array(
		'default'		=> '8',
		'sanitize_callback'	=> 'sanitize_text_field'
		
		)
	);
	
	$wp_customize->add_control('medical_portfolio_woo_pronum',
	        array(
			'label'        => __( 'Number of product to show. Default: 8', 'medical-portfolio' ),
	            'section' => 'medical_portfolio_frontpage_woo',
	            'settings' => 'medical_portfolio_woo_pronum',
	            'type' => 'text'
	        )
	);
		
// Posts Sections		
		
$wp_customize-> add_section('medical_portfolio_frontpage_post',
    array(
    	'title'			=> __('Front Page Posts','medical-portfolio'),
    	'description'	=> __('Only for front page posts.','medical-portfolio'),
    	'priority'		=> 3,
    	'panel'			=> 'medical_portfolio_frontpageindex'
    	)
    );
    
	
$wp_customize->add_setting('medical_portfolio_enablefrontpost',
    array(
			'default'			=> 'enable',
			'type'				=> 'theme_mod',
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
    )
);
	$wp_customize->add_control('medical_portfolio_enablefrontpost',
    array(
        'type' => 'radio',
		'label'        => __( 'Enable or Disable Posts', 'medical-portfolio' ),
		'settings'   => 'medical_portfolio_enablefrontpost',
        'section' => 'medical_portfolio_frontpage_post',
        'choices' => array(
            'enable' => __('Enable','medical-portfolio'),
            'disable' => __('Disable','medical-portfolio'),
        ) ));
	
	$wp_customize->add_setting('medical_portfolio_post_sec_text',
	array(
		'default'		=> 'Latest Blog Posts',
		'sanitize_callback'	=> 'sanitize_text_field'
		
		)
	);
	
	$wp_customize->add_control('medical_portfolio_post_sec_text',
	        array(
			'label'        => __( 'Title of Posts', 'medical-portfolio' ),
	            'section' => 'medical_portfolio_frontpage_post',
	            'settings' => 'medical_portfolio_post_sec_text',
	            'type' => 'text'
	        )
	);

	$wp_customize->add_setting('medical_portfolio_post_pronum',
	array(
		'default'		=> '4',
		'sanitize_callback'	=> 'sanitize_text_field'
		
		)
	);
	
	$wp_customize->add_control('medical_portfolio_post_pronum',
	        array(
			'label'        => __( 'Number of post to show. Default: 4', 'medical-portfolio' ),
	            'section' => 'medical_portfolio_frontpage_post',
	            'settings' => 'medical_portfolio_post_pronum',
	            'type' => 'text'
	        )
	);
				

$wp_customize->add_setting('medical_portfolio_post_prodate',	
	array(
		'default'			=> 'enable',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('medical_portfolio_post_prodate',
	 array (                             
		'type' => 'radio',
		'label' => __('Date stamp in post','medical-portfolio'),
		'settings'   => 'medical_portfolio_post_prodate',
		'section' => 'medical_portfolio_frontpage_post',
		'choices' => array(
		'enable' => __('Enable','medical-portfolio'),
		'disable' => __('Disable','medical-portfolio'),
	 ) 
	 ));
/**************************************************
* Settings
***************************************************/

$wp_customize->add_setting('radio_menu',
    array(
        'default'			=> 'fixed',
			'type'				=> 'theme_mod',
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
    )
);
$wp_customize->add_setting( 'topnavbgcolor' , array(
    'default'     => '#40ACEC',
    'transport'   => 'refresh',
	'sanitize_callback'	=> 'sanitize_hex_color',
) );
$wp_customize->add_setting( 'topnavbgcolorsub' , array(
    'default'     => '#20598a',
    'transport'   => 'refresh',
	'sanitize_callback'	=> 'sanitize_hex_color',
) );
$wp_customize->add_setting( 'topnavbgcolorfont' , array(
    'default'     => '#ffffff',
    'transport'   => 'refresh',
	'sanitize_callback'	=> 'sanitize_hex_color',
) );
$wp_customize->add_setting('search_setting',
    array(
        'default'			=> 'show',
			'type'				=> 'theme_mod',
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
    )
);



/**************************************************
* Slider
***************************************************/
$wp_customize->add_section('slider', array(
    'title' => __('Banner Image & Text', 'medical-portfolio'),
    'description'=> sprintf(__('Control Theme Banner from Here : Recommended image size width: 1920px , Height:430px ', 'medical-portfolio')),
    'priority' => 100
    ));

$wp_customize->add_setting('slider_control',	
	array(
		'default'			=> 'enable',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('slider_control',
                         array (                             
							'type' => 'radio',
							'label' => __('Slider Control','medical-portfolio'),
							'settings'   => 'slider_control',
							'section' => 'slider',
							'priority' => 1,
							'choices' => array(
							'enable' => __('Enable','medical-portfolio'),
							'disable' => __('Disable','medical-portfolio'),
                         )
						 ));
						 
	$wp_customize -> add_setting('slideimg', array(
		'default' => '', 
		'type' => 'theme_mod',
		'sanitize_callback' => 'medical_portfolio_sanitize_image'

	));

	$wp_customize -> add_control(new WP_Customize_Image_Control($wp_customize, 'slideimg', array(
		'label' => __( 'Slide ', 'medical-portfolio'),
		'section' => 'slider',
		'settings' => 'slideimg',
		'priority' => 2
	))); 

	
	$wp_customize->add_setting( 'slidebntext', array(
            'default'        => '',
            'sanitize_callback'        => 'wp_kses_post',
        ) );
    $wp_customize->add_control('slidebntext', array(
			'settings'		=> 'slidebntext',
			'section'		=> 'slider',
			'type'			=> 'textarea',
			'label'			=> __( 'Custom Text on banner', 'medical-portfolio' ),
		)
	);
/**************************************************
* Layout
***************************************************/
// Post Settings
	$wp_customize->add_section( 'medical_portfolio_panel_layout' , array(
    'title'      => __( 'Layout', 'medical-portfolio' ),
	'panel'			=> 'medical_portfolio_panel_design',
    'priority'   => 2,
) );


//Author Profile
 $wp_customize->add_setting('website_layout',	
	array(
		'default'			=> 'rightside',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('website_layout',
                         array (                             
							'type' => 'radio',
							'label' => __('Post and Page Layout','medical-portfolio'),
							'settings'   => 'website_layout',
							'section' => 'medical_portfolio_panel_layout',
							'choices' => array(          
							'rightside' => __('Right Sidebar','medical-portfolio'),
							'left' => __('Left Sidebar','medical-portfolio'),
							'full' => __('Full Width [No sidebar]','medical-portfolio'),
                         )
						 ));	
	
/**************************************************
* Fonts
***************************************************/
$font_array = array('Raleway','Khula','Open Sans','Indie Flower','Droid Sans','Droid Serif','Roboto','Roboto Condensed','Lato','Bree Serif','Oswald','Slabo','Lora','Source Sans Pro','PT Sans','Ubuntu','Lobster','Arimo','Bitter','Noto Sans','Fjalla One','PT Sans Narrow','Poiret One','Passion One','Arvo','Inconsolata','Shadows Into Light','Pacifico','Dancing Script','Architects Daughter','Sigmar One','Righteous','Amatic SC','Orbitron','Chewy','Lobster Two','Gloria Hallelujah','Lekton','Almendra Display','Swanky and Moo Moo','Hanalei Fill','Uncial Antiqua','Rouge Script','Engagement','Bonbon','Caesar Dressing','Kenia','Lemon','Stardos Stencil','Bilbo','Macondo','Delius Unicase','Butcherman','Monoton','Nosifer','Codystar','Fontdiner Swanky','Diplomata SC','Snowburst One','Faster One','Rock Salt','Eater');
$fonts = array_combine($font_array, $font_array);
// Body Fonts
	$wp_customize->add_section( 'medical_portfolio_panel_bodyfonts' , array(
    'title'      => __( 'Body Fonts', 'medical-portfolio' ),
	'panel'			=> 'medical_portfolio_panel_advance',
    'priority'   => 1,
) );	
$wp_customize->add_setting(
	'medical_portfolio_title_font',
	array(
		'default'=> 'Open Sans',
		'sanitize_callback' => 'medical_portfolio_sanitize_gfont' 
		)
);
$wp_customize->add_control(
	'medical_portfolio_title_font',array(
			'label' => __('Title','medical-portfolio'),
			'settings' => 'medical_portfolio_title_font',
			'section'  => 'medical_portfolio_panel_bodyfonts',
			'type' => 'select',
			'choices' => $fonts,
		)
);
$wp_customize->add_setting(
		'medical_portfolio_body_font',
			array(	'default'=> 'Open Sans',
					'sanitize_callback' => 'medical_portfolio_sanitize_gfont' )
	);

$wp_customize->add_control(
		'medical_portfolio_body_font',array(
				'label' => __('Body','medical-portfolio'),
				'settings' => 'medical_portfolio_body_font',
				'section'  => 'medical_portfolio_panel_bodyfonts',
				'type' => 'select',
				'choices' => $fonts
			)
	);
/**************************************************
* Tinymce Editor - Header
***************************************************/
  
  $wp_customize->add_section('headerinfo_section' ,  array(
    'title' => __('Header Info Area', 'medical-portfolio'),
	'panel'			=> 'medical_portfolio_panel_advance',
    'priority' => 100
  ));

$wp_customize->add_setting(	'header_infoleft',
	array(
		'default'		=> '',
		'sanitize_callback'	=> 'wp_kses_post'
	));

$wp_customize->add_control(	'header_infoleft',
	array(
		'section' => 'headerinfo_section',
		'label' => __('Left side text','medical-portfolio'),
		'settings' => 'header_infoleft',
		'type' => 'textarea'
	));

$wp_customize->add_setting(	'header_inforight',
	array(
		'default'		=> '',
		'sanitize_callback'	=> 'wp_kses_post'
	));

$wp_customize->add_control(	'header_inforight',
	array(
		'section' => 'headerinfo_section',
		'label' => __('Right side text','medical-portfolio'),
		'settings' => 'header_inforight',
		'type' => 'textarea'
	));

	
/**************************************************
* Post Settings
***************************************************/
// Post Settings
	$wp_customize->add_section( 'medical_portfolio_panel_postsettings' , array(
    'title'      => __( 'Post Settings', 'medical-portfolio' ),
	//'panel'			=> 'medical_portfolio_panel_advance',
    'priority'   => 2,
) );


$wp_customize->add_setting('random_post',	
	array(
		'default'			=> 'enable',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('random_post',
                         array (                             
							'type' => 'radio',
							'label' => __('Random Post Below Post','medical-portfolio'),
							'settings'   => 'random_post',
							'section' => 'medical_portfolio_panel_postsettings',
							'choices' => array(
							'enable' => __('Enable','medical-portfolio'),
							'disable' => __('Disable','medical-portfolio'),
                         )
						 ));						
$wp_customize->add_setting('medical_portfolio_author_profile',	
	array(
		'default'			=> 'enable',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('medical_portfolio_author_profile',
                         array (                             
							'type' => 'radio',
							'label' => __('Show Author Profile in Post and Pages','medical-portfolio'),
							'settings'   => 'medical_portfolio_author_profile',
							'section' => 'medical_portfolio_panel_postsettings',
							'choices' => array(
							'enable' => __('Enable','medical-portfolio'),
							'disable' => __('Disable','medical-portfolio'),
                         )
						 ));
	
$wp_customize->add_setting('singlepost_thumb',	
	array(
		'default'			=> 'enable',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('singlepost_thumb',
                         array (                             
							'type' => 'radio',
							'label' => __('Thumbnail in Single Post','medical-portfolio'),
							'settings'   => 'singlepost_thumb',
							'section' => 'medical_portfolio_panel_postsettings',
							'choices' => array(
							'enable' => __('Enable','medical-portfolio'),
							'disable' => __('Disable','medical-portfolio'),
                         )
						 ));
$wp_customize->add_setting('singlepost_date',	
	array(
		'default'			=> 'enable',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('singlepost_date',
                         array (                             
							'type' => 'radio',
							'label' => __('Date in single post','medical-portfolio'),
							'settings'   => 'singlepost_date',
							'section' => 'medical_portfolio_panel_postsettings',
							'choices' => array(
							'enable' => __('Enable','medical-portfolio'),
							'disable' => __('Disable','medical-portfolio'),
                         )
						 ));						 
$wp_customize->add_setting('singlepost_authortitle',	
	array(
		'default'			=> 'enable',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('singlepost_authortitle',
                         array (                             
							'type' => 'radio',
							'label' => __('Author name in single post','medical-portfolio'),
							'settings'   => 'singlepost_authortitle',
							'section' => 'medical_portfolio_panel_postsettings',
							'choices' => array(
							'enable' => __('Enable','medical-portfolio'),
							'disable' => __('Disable','medical-portfolio'),
                         )
						 ));	
$wp_customize->add_setting('singlepost_cate',	
	array(
		'default'			=> 'enable',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('singlepost_cate',
                         array (                             
							'type' => 'radio',
							'label' => __('Category in single post','medical-portfolio'),
							'settings'   => 'singlepost_cate',
							'section' => 'medical_portfolio_panel_postsettings',
							'choices' => array(
							'enable' => __('Enable','medical-portfolio'),
							'disable' => __('Disable','medical-portfolio'),
                         )
						 ));
$wp_customize->add_setting('singlepost_tags',	
	array(
		'default'			=> 'enable',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('singlepost_tags',
                         array (                             
							'type' => 'radio',
							'label' => __('Tags in single post','medical-portfolio'),
							'settings'   => 'singlepost_tags',
							'section' => 'medical_portfolio_panel_postsettings',
							'choices' => array(
							'enable' => __('Enable','medical-portfolio'),
							'disable' => __('Disable','medical-portfolio'),
                         )
						 ));						 
/**************************************************
* WooCommerce
***************************************************/
// Woocommerce
	$wp_customize->add_section( 'medical_portfolio_woo_section' , array(
    'title'      => __( 'WooCommerce', 'medical-portfolio' ),
	//'panel'			=> 'medical_portfolio_panel_design',
    'priority'   => 67,
) );
$wp_customize->add_setting('medical_portfolio_woo_myaccount',	
	array(
		'default'			=> '',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'transport'   => 'post',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('medical_portfolio_woo_myaccount', array (                             
				'type' => 'radio',
				'label' => __('My Account/ Login','medical-portfolio'),
				'settings'   => 'medical_portfolio_woo_myaccount',
				'section' => 'medical_portfolio_woo_section',
				'choices' => array(
				'enable' => __('Enable','medical-portfolio'),
				'disable' => __('Disable','medical-portfolio'),
			 )
			 ));
$wp_customize->add_setting('medical_portfolio_woo_cart',	
	array(
		'default'			=> '',
		'type'				=> 'theme_mod',
		'transport'   => 'post',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('medical_portfolio_woo_cart', array (                             
				'type' => 'radio',
				'label' => __('Cart','medical-portfolio'),
				'settings'   => 'medical_portfolio_woo_cart',
				'section' => 'medical_portfolio_woo_section',
				'choices' => array(
				'enable' => __('Enable','medical-portfolio'),
				'disable' => __('Disable','medical-portfolio'),
			 )
			 ));
			 
			 
$wp_customize->add_setting('medical_portfolio_woo_removemeta',	
	array(
		'default'			=> '',
		'type'				=> 'theme_mod',
		'transport'   => 'post',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('medical_portfolio_woo_removemeta', array (                             
				'type' => 'radio',
				'label' => __('Remove Category & Tags from Product','medical-portfolio'),
				'settings'   => 'medical_portfolio_woo_removemeta',
				'section' => 'medical_portfolio_woo_section',
				'choices' => array(
				'enable' => __('Hide','medical-portfolio'),
				'disable' => __('Show','medical-portfolio'),
			 )
			 ));			 
// Woocommerce Settings
$wp_customize->add_setting('medical_portfolio_woo_lightbox',	
	array(
		'default'			=> '',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('medical_portfolio_woo_lightbox', array (                             
				'type' => 'radio',
				'label' => __('LightBox Open Images','medical-portfolio'),
				'settings'   => 'medical_portfolio_woo_lightbox',
				'section' => 'medical_portfolio_woo_section',
				'choices' => array(
				'enable' => __('Enable','medical-portfolio'),
				'disable' => __('Disable','medical-portfolio'),
			 )
			 ));
$wp_customize->add_setting('medical_portfolio_woo_zoom',	
	array(
		'default'			=> '',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('medical_portfolio_woo_zoom', array (                             
				'type' => 'radio',
				'label' => __('Zoom Product Images','medical-portfolio'),
				'settings'   => 'medical_portfolio_woo_zoom',
				'section' => 'medical_portfolio_woo_section',
				'choices' => array(
				'enable' => __('Enable','medical-portfolio'),
				'disable' => __('Disable','medical-portfolio'),
			 )
			 ));	
$wp_customize->add_setting('medical_portfolio_woo_slider',	
	array(
		'default'			=> '',
		'type'				=> 'theme_mod',
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'medical_portfolio_sanitize_select'
	));
$wp_customize->add_control('medical_portfolio_woo_slider', array (                             
				'type' => 'radio',
				'label' => __('Slide Product Images','medical-portfolio'),
				'settings'   => 'medical_portfolio_woo_slider',
				'section' => 'medical_portfolio_woo_section',
				'choices' => array(
				'enable' => __('Enable','medical-portfolio'),
				'disable' => __('Disable','medical-portfolio'),
			 )
			 ));	
/**************************************************
* Footer Copyright
***************************************************/
	$wp_customize-> add_section(
    'medical_portfolio_custom_footer',
    array(
    	'title'			=> __('Custom Footer Text','medical-portfolio'),
    	'description'	=> __('Enter your Own Copyright Text.','medical-portfolio'),
    	'priority'		=> 3,
    	'panel'			=> 'medical_portfolio_panel_advance'
    	)
    );
    
	$wp_customize->add_setting(
	'medical_portfolio_footer_text',
	array(
		'default'		=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
		)
	);
	
	$wp_customize->add_control(	 
	       'medical_portfolio_footer_text',
	        array(
	            'section' => 'medical_portfolio_custom_footer',
	            'settings' => 'medical_portfolio_footer_text',
	            'type' => 'text'
	        )
	);
	
/**************************************************
* Social
***************************************************/
	// Social Icons
	$wp_customize->add_section('medical_portfolio_social_section', array(
			'title' => __('Social Icons','medical-portfolio'),
			'priority' => 44 ,
				'panel'	=> 'medical_portfolio_panel_advance'
	));
	
	$social_networks = array( //Redefinied in Sanitization Function.
					'none' => __('-','medical-portfolio'),
					'facebook-square' => __('Facebook','medical-portfolio'),
					'twitter-square' => __('Twitter','medical-portfolio'),
					'google-plus-square' => __('Google Plus','medical-portfolio'),
					'instagram' => __('Instagram','medical-portfolio'),
					'rss' => __('RSS Feeds','medical-portfolio'),
					'vine' => __('Vine','medical-portfolio'),
					'vimeo-square' => __('Vimeo','medical-portfolio'),
					'youtube-square' => __('Youtube','medical-portfolio'),
					'flickr' => __('Flickr','medical-portfolio'),
				);
				
	$social_count = count($social_networks);
				
	for ($x = 1 ; $x <= ($social_count - 3) ; $x++) :
			
		$wp_customize->add_setting(
			'medical_portfolio_social_'.$x, array(
				'sanitize_callback' => 'medical_portfolio_sanitize_social',
				'default' => 'none'
			));

		$wp_customize->add_control( 'medical_portfolio_social_'.$x, array(
					'settings' => 'medical_portfolio_social_'.$x,
					'label' => __('Icon ','medical-portfolio').$x,
					'section' => 'medical_portfolio_social_section',
					'type' => 'select',
					'choices' => $social_networks,			
		));
		
		$wp_customize->add_setting(
			'medical_portfolio_social_url'.$x, array(
				'sanitize_callback' => 'esc_url_raw'
			));

		$wp_customize->add_control( 'medical_portfolio_social_url'.$x, array(
					'settings' => 'medical_portfolio_social_url'.$x,
					'description' => __('Icon ','medical-portfolio').$x.__(' Url','medical-portfolio'),
					'section' => 'medical_portfolio_social_section',
					'type' => 'url',
					'choices' => $social_networks,			
		));
		
	endfor;
	
	function medical_portfolio_sanitize_social( $input ) {
		$social_networks = array(
					'none' ,
					'facebook-square',
					'twitter-square',
					'google-plus-square',
					'instagram',
					'rss',
					'vine',
					'vimeo-square',
					'youtube-square',
					'flickr'
				);
		if ( in_array($input, $social_networks) )
			return $input;
		else
			return '';	
	}	
	
	
/**************************************************
* Control
***************************************************/

	$wp_customize->add_control('radio_menu',
    array(
        'type' => 'radio',
        'label' => __('Top Navigation Position','medical-portfolio'),
		'settings'   => 'radio_menu',
        'section' => 'top_navi_colorbg',
        'choices' => array(
            'fixed' => __('Float','medical-portfolio'),
            'relative' => __('Fixed','medical-portfolio'),
        ) ));		
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'topnavbgcolor', array(
	'label'        => __( 'Top Navigation Color', 'medical-portfolio' ),
	'section'    => 'top_navi_colorbg',
	'settings'   => 'topnavbgcolor',
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'topnavbgcolorsub', array(
	'label'        => __( 'Sub Menu Color', 'medical-portfolio' ),
	'section'    => 'top_navi_colorbg',
	'settings'   => 'topnavbgcolorsub',
	) ) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'topnavbgcolorfont', array(
	'label'        => __( 'Top Menu Font Color', 'medical-portfolio' ),
	'section'    => 'top_navi_colorbg',
	'settings'   => 'topnavbgcolorfont',
	) ) );
$wp_customize->add_control('search_setting',
    array(
        'type' => 'radio',
        'label' => __('Search Bar','medical-portfolio'),
		'settings'   => 'search_setting',
        'section' => 'top_navi_colorbg',
        'choices' => array(
            'show' => __('Show','medical-portfolio'),
            'hide' => __('Hide','medical-portfolio'),
        ) ));
		

/**************************************************
* Customizer Panels
***************************************************/	
	$wp_customize->add_panel('medical_portfolio_panel_design',
		array(
			'priority' 			=> 12,
			'capability' 		=> 'edit_theme_options',
			'theme_supports'	=> '',
			'title' 			=> __( 'Color, Design', 'medical-portfolio' ),
			'description' 		=> __( 'Configure color and layout settings for the medical_portfolio Theme', 'medical-portfolio' ),
		)
	);
	$wp_customize->add_panel('medical_portfolio_panel_advance',
		array(
			'priority' 			=> 13,
			'capability' 		=> 'edit_theme_options',
			'theme_supports'	=> '',
			'title' 			=> __( 'Advance Settings', 'medical-portfolio' ),
			'description' 		=> __( 'Advance Settings related to footer copyright and Enable options', 'medical-portfolio' ),
		)
	);
		

}
add_action( 'customize_register', 'medical_portfolio_customize_register' );




/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function medical_portfolio_customize_preview_js() {
	wp_enqueue_script( 'medical_portfolio_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20130508', true );
}
add_action( 'customize_preview_init', 'medical_portfolio_customize_preview_js' );

/************************************
 * sanitization callback.
 ***********************************/
function medical_portfolio_sanitize_css( $css ) {
	return wp_strip_all_tags( $css );
}
function medical_portfolio_sanitize_hex_color( $hex_color, $setting ) {
	// Sanitize $input as a hex value without the hash prefix.
	$hex_color = sanitize_hex_color( $hex_color );
	
	// If $input is a valid hex value, return it; otherwise, return the default.
	return ( ! null( $hex_color ) ? $hex_color : $setting->default );
}
function medical_portfolio_sanitize_select( $input, $setting ) {
	
	// Ensure input is a slug.
	$input = sanitize_key( $input );
	
	// Get list of choices from the control associated with the setting.
	$choices = $setting->manager->get_control( $setting->id )->choices;
	
	// If the input is a valid key, return it; otherwise, return the default.
	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}
function medical_portfolio_sanitize_gfont( $input ) {
		if ( in_array($input, array('Helvetica Neue','Helvetica','Raleway','Khula','Open Sans','Indie Flower','Droid Sans','Droid Serif','Roboto','Roboto Condensed','Lato','Bree Serif','Oswald','Slabo','Lora','Source Sans Pro','PT Sans','Ubuntu','Lobster','Arimo','Bitter','Noto Sans','Fjalla One','PT Sans Narrow','Poiret One','Passion One','Arvo','Inconsolata','Shadows Into Light','Pacifico','Dancing Script','Architects Daughter','Sigmar One','Righteous','Amatic SC','Orbitron','Chewy','Lobster Two','Gloria Hallelujah','Lekton','Almendra Display','Swanky and Moo Moo','Hanalei Fill','Uncial Antiqua','Rouge Script','Engagement','Bonbon','Caesar Dressing','Kenia','Lemon','Stardos Stencil','Bilbo','Macondo','Delius Unicase','Butcherman','Monoton','Nosifer','Codystar','Fontdiner Swanky','Diplomata SC','Snowburst One','Faster One','Rock Salt','Eater') ) )
			return $input;
		else
			return '';	
	}
	
	
	function medical_portfolio_sanitize_image( $image, $setting ) {
	/*
	 * Array of valid image file types.
	 *
	 * The array includes image mime types that are included in wp_get_mime_types()
	 */
    $mimes = array(
        'jpg|jpeg|jpe' => 'image/jpeg',
        'gif'          => 'image/gif',
        'png'          => 'image/png',
        'bmp'          => 'image/bmp',
        'tif|tiff'     => 'image/tiff',
        'ico'          => 'image/x-icon'
    );
	// Return an array with file extension and mime_type.
    $file = wp_check_filetype( $image, $mimes );
	// If $image has a valid mime_type, return it; otherwise, return the default.
    return ( $file['ext'] ? $image : $setting->default );
}